=== modified file 'docs/aggregatefunctions.rst'
--- docs/aggregatefunctions.rst	2011-01-14 05:25:23 +0000
+++ docs/aggregatefunctions.rst	2011-01-17 22:15:30 +0000
@@ -1,19 +1,45 @@
 Aggregate Functions
-===================
+===================
 
-*SQL aggregate functions are calculated from values in a column, and return a single value.*
+SQL group (aggregate) functions operate on sets of values. If you use an aggregate function in a statement containing no GROUP BY clause, it is equivalent to grouping on all rows.
 
 General syntax for aggregate functions is: ::
 
 	SELECT "function type" ("column_name")
-	FROM "table_name"
-
-The following are examples of aggregate functions:
-
-    * AVG() - Returns the average value
-    * COUNT() - Returns the number of rows
-    * FIRST() - Returns the first value
-    * LAST() - Returns the last value
-    * MAX() - Returns the largest value
-    * MIN() - Returns the smallest value
-    * SUM() - Returns the sum
+	FROM "table_name";
+
+The following are examples of aggregate functions:
+
+**AVG**:  Return the average value of the argument. (Does not work with temporal values unless first converted to numeric values.)
+
+:doc:`count`
+(DISTINCT):  Return the count of a number of different values
+
+:doc:`count`:  Return a count of the number of rows returned
+	
+**GROUP_CONCAT**:  Return a concatenated string
+
+**MAX**:  Return the maximum value
+
+**MIN**:  Return the minimum value
+
+**STD**:  Return the population standard deviation
+
+**STDDEV_POP**:  Return the population standard deviation
+
+**STDDEV_SAMP**:  Return the sample standard deviation
+
+**STDDEV**:  Return the population standard deviation
+
+**SUM**:  Return the sum. (Does not work with temporal values unless first converted to numeric values.)
+
+**VAR_POP**:  Return the population standard variance
+
+**VAR_SAMP**:  Return the sample variance
+
+**VARIANCE**:  Return the population standard variance
+
+.. toctree::
+   :hidden: 
+
+   count

=== modified file 'docs/clients/drizzledump.rst'
--- docs/clients/drizzledump.rst	2011-01-07 03:04:54 +0000
+++ docs/clients/drizzledump.rst	2011-01-17 21:08:33 +0000
@@ -260,22 +260,25 @@
 
 When you migrate from MySQL to Drizzle, the following conversions are required:
 
-MyISAM -> InnoDB
-FullText -> drop it (with stderr warning)
-int unsigned -> bigint
-tinyint -> int
-smallint -> int
-mediumint -> int
-tinytext -> text
-mediumtext -> text
-longtext -> text
-tinyblob -> blob
-mediumblob -> blob
-longblob -> blob
-time -> int (of seconds)
-year -> int
-set -> text
-date/datetime default 0000-00-00 -> default NULL (Currently, ALL date columns have their DEFAULT set to NULL on migration)
-date/datetime NOT NULL columns -> NULL
-any date data containing 0000-00-00 -> NULL
-enum-> DEFAULT NULL
\ No newline at end of file
+ * MyISAM -> InnoDB
+ * FullText -> drop it (with stderr warning)
+ * int unsigned -> bigint
+ * tinyint -> int
+ * smallint -> int
+ * mediumint -> int
+ * tinytext -> text
+ * mediumtext -> text
+ * longtext -> text
+ * tinyblob -> blob
+ * mediumblob -> blob
+ * longblob -> blob
+ * time -> int (of seconds)
+ * year -> int
+ * set -> text
+ * date/datetime default 0000-00-00 -> default NULL (Currently, ALL date columns have their DEFAULT set to NULL on migration)
+ * date/datetime NOT NULL columns -> NULL
+ * any date data containing 0000-00-00 -> NULL
+ * TIME -> INT of the number of seconds*
+ * enum-> DEFAULT NULL
+
+* This prevents data loss since MySQL's TIME data type has a range of -838:59:59 - 838:59:59, and Drizzle's TIME type has a range of 00:00:00 - 23:59:61.999999.

=== added file 'docs/count.rst'
--- docs/count.rst	1970-01-01 00:00:00 +0000
+++ docs/count.rst	2011-01-18 00:10:25 +0000
@@ -0,0 +1,31 @@
+COUNT
+-----
+
+Take the following "Nodes" table, where 'nodes' are user-contributed content:
+
++--------+-------------------+------------+----------------+-------------------+
+|NodeID  |ContributionDate   |NodeSize    |NodePopularity  |UserName           |
++--------+-------------------+------------+----------------+-------------------+
+|1	 |12/22/2010         |160	  |2	           |Smith              |
++--------+-------------------+------------+----------------+-------------------+
+|2	 |08/10/2010	     |190	  |2	           |Johnson            |
++--------+-------------------+------------+----------------+-------------------+
+|3  	 |07/13/2010	     |500	  |5	           |Baldwin            |
++--------+-------------------+------------+----------------+-------------------+
+|4	 |07/15/2010         |420	  |2               |Smith              |
++--------+-------------------+------------+----------------+-------------------+
+|5	 |12/22/2010         |1000	  |4               |Wood               |
++--------+-------------------+------------+----------------+-------------------+
+|6       |10/2/2010          |820	  |4	           |Smith              |
++--------+-------------------+------------+----------------+-------------------+
+
+The SQL COUNT function returns the number of rows in a table satisfying the criteria specified in the WHERE clause. If we want to count how many orders has made a customer with CustomerName of Smith, we will use the following SQL COUNT expression: ::
+
+	SELECT COUNT * FROM Nodes
+	WHERE UserName = "Smith";
+
+In the above statement, the COUNT keyword returns the number 3, because the user Smith has 3 total nodes.
+
+If you don’t specify a WHERE clause when using the COUNT keyword, your statement will simply return the total number of rows in the table, which would be 6 in this example: ::
+
+	SELECT COUNT * FROM Nodes;

=== modified file 'docs/date_time_data_types.rst'
--- docs/date_time_data_types.rst	2011-01-14 05:20:19 +0000
+++ docs/date_time_data_types.rst	2011-01-17 21:08:33 +0000
@@ -20,15 +20,13 @@
 TIMESTAMP
 ---------
 
-To create a TIMESTAMP column that uses microseconds you simply need to specify TIMESTAMP(6) in your table definition, for example: ::
+To create a TIMESTAMP column that uses microseconds you simply need to specify TIMESTAMP in your table definition, for example: ::
 
 	CREATE TABLE `t1` (
 	`a` INT DEFAULT NULL,
-	`b` TIMESTAMP(6) NULL DEFAULT NULL
+	`b` TIMESTAMP NULL DEFAULT NULL
 	) ENGINE=InnoDB
 
-FIXME: why the number 6 ?
-
 You can then use the following (but note that ON DEFAULT/UPDATE CURRENT_TIMESTAMP works with microseconds as well): ::
 
 	insert into t1 values (1, '2010-01-10 07:32:43.234567');
@@ -49,10 +47,10 @@
 TIME
 ----
 
-Drizzle's TIME data type has a range of 00:00:00 - 24:59:59, while MySQL's TIME data type has a range of -838:59:59 - 838:59:59.
-
-FIXME: should be to 23hrs. in fact, to be compliant, it should be to at a minimum 23:59:61.999999.
-
-FIXME: should also mention that this brings Drizzle closer to the SQL standard. Negative time is not meant to be there at all.
+Drizzle's TIME data type has a range of 00:00:00 - 23:59:61.999999, while MySQL's TIME data type has a range of -838:59:59 - 838:59:59.
+
+This brings Drizzle closer to the SQL standard. Negative time is not meant to be there at all.
 
 To prevent data loss to this type when converting from MySQL -> Drizzle, the conversion changes TIME to an INT of the number of seconds. For example, 00:00:00 becomes 0, 01:00:00 becomes 3600, and -01:00:00 becomes -3600.
+
+More information on this can be found in the "MySQL Migration Using Drizzledump" section of the :doc:`clients/drizzledump` chapter.

=== modified file 'docs/functions.rst'
--- docs/functions.rst	2011-01-04 19:30:06 +0000
+++ docs/functions.rst	2011-01-17 21:08:33 +0000
@@ -1,10 +1,12 @@
 SQL Functions
 =============
 
-Several SQL functions are built into Drizzle--functions perform calculations on data. They can be divided into two general types: 
+Several SQL functions are built into Drizzle--functions perform calculations on data. They can be be understood in categories: 
    
 .. toctree::
    :maxdepth: 2
 
+   mathematical 
    aggregatefunctions
-   scalarfunctions
\ No newline at end of file
+   scalarfunctions
+  

=== modified file 'docs/index.rst'
--- docs/index.rst	2011-01-14 04:34:23 +0000
+++ docs/index.rst	2011-01-17 21:08:33 +0000
@@ -40,6 +40,7 @@
 
    queries
    functions
+   data_types
    ddl
    dml
    columntypes 
@@ -51,13 +52,6 @@
    transactional 
    administrative
 
-Data Types:
------------
-.. toctree::
-   :maxdepth: 2
-
-   data_types
-
 User Level Topics:
 ------------------
 .. toctree::

=== added file 'docs/mathematical.rst'
--- docs/mathematical.rst	1970-01-01 00:00:00 +0000
+++ docs/mathematical.rst	2011-01-17 22:15:30 +0000
@@ -0,0 +1,84 @@
+Mathematical Functions and Operators
+====================================
+
+Mathematical operators are provided for many Drizzle types. ::
+
+	========    ==================   ==========  ======
+	Operator    Description          Example     Result
+	========    ==================   ==========  ======
+	+           addition             2 + 3       5
+	-           subtraction          2 - 3       -1
+	*           multiplication       2 * 3       6
+	/           division             4 / 2       2
+	%           modulo (remainder)   5 % 4       1
+	|/          square root          |/ 25.0     5
+	||/         cube root            ||/ 27.0  3
+	!           factorial            5 !         120
+	!!          factorial            !! 5        120
+	@           absolute value       @ -5.0      5
+	========    ==================   ==========  ======
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+

=== modified file 'docs/mysql_differences.rst'
--- docs/mysql_differences.rst	2011-01-07 03:04:54 +0000
+++ docs/mysql_differences.rst	2011-01-17 21:08:33 +0000
@@ -112,6 +112,7 @@
 
 INFORMATION_SCHEMA
 ------------------
+
 The INFORMATION_SCHEMA provides access to database metadata.
 
 The INFORMATION_SCHEMA in Drizzle is strictly ANSI compliant. If you write
@@ -176,18 +177,19 @@
  * CREATE FUNCTION
  * CONVERT
  * SET NAMES
+ * Multi-table delete and multi-table update code was removed and can be accomplished through subqueries. More detailed information can be found in the :doc:`dml` section.
 
 Operators Removed
 -----------------
 
-Bit operators: 
-* &&
-* >>
-* <<
-* ~
-* ^
-* |
-* &
+Bit operators
+ * &&
+ * >>
+ * <<
+ * ~
+ * ^
+ * '|'
+ * &
 
 Removed functions
 -----------------
@@ -198,6 +200,7 @@
 
 Keywords removed
 ----------------
+
  * BIT_AND
  * BIT_OR
  * BIT_XOR

=== modified file 'docs/update.rst'
--- docs/update.rst	2011-01-14 05:09:34 +0000
+++ docs/update.rst	2011-01-17 17:18:16 +0000
@@ -7,3 +7,10 @@
 
 UPDATE TABLE_1 SET a="1" WHERE <condition>;
 
+Multi-table delete and multi-table update code was removed from Drizzle.
+
+Multi-update/delete can be accomplished through subqueries. For example: ::
+
+	UPDATE tableX SET tableXfield = (SELECT MAX(tableY.tableYfield) FROM tableY WHERE tableX.tableXfield = tableY.tableYfield)
+
+In other database frameworks, multi-update and multi-delete are used to change information in *one* table, but the rows to change are determined by using more than one table. In that case, subqueries work to address the issue of changing information in one table based on information in more than one table.
\ No newline at end of file

